==> haskell-unbounded-delays-0.1.1.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-5DQoecUWtqrFUxKuQlOwPb
key: unbounded-delays-0.1.1.0-5DQoecUWtqrFUxKuQlOwPb
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: 662aeb6e5abcf838451a8d906b7887cd
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-5DQoecUWtqrFUxKuQlOwPb
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-KvddZgm6oGyK2gQebOtQdi
key: unbounded-delays-0.1.1.0-KvddZgm6oGyK2gQebOtQdi
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: 21606fb0755043239102472e86d97688
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-KvddZgm6oGyK2gQebOtQdi
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
